F-1.LT - F1, F-1, Formulė-1, WRC, MotoGP, autosportas
Description: Viskas apie „Formulę-1“ lietuvių kalba. Naujienos, straipsniai, nuotraukos, komentarai ir diskusijos. Informacija apie kitas autosporto šakas: WRC, GP2, „Formulę-2“. „MotoGP“ apžvalgos.

# Prisijungimas

Vartotojo vardas:

Slaptažodis:

Prisiminti

Registracija
Naujienos el. paštu
Priminti slaptažodį

# Pilotų įskaita

2014 m. galutinė įskaita:
1 | L. Hamiltonas | 384
2 | N. Rosbergas | 317
3 | D. Ricciardo | 238
4 | V. Bottas | 186
5 | S. Vettelis | 167
6 | F. Alonso | 161
7 | F. Massa | 134
8 | J. Buttonas | 126
9 | N. Hulkenbergas | 96
10 | S. Perezas | 59
11 | K. Magnussenas | 55
12 | K. Raikkonenas | 55
13 | J.-E. Vergne | 22
14 | R. Grosjeanas | 8
15 | D. Kvyatas | 8
16 | P. Maldonado | 2
17 | J. Bianchi | 2
18 | A. Sutilas | 0
19 | M. Ericssonas | 0
20 | E. Gutierrezas | 0
21 | M. Chiltonas | 0
22 | K. Kobayashi | 0
23 | W. Stevensas | 0
24 | A. Lottereris | 0

# Komandų įskaita

2014 m. galutinė įskaita:
1 | Mercedes | 701
2 | Red Bull | 405
3 | Williams | 320
4 | Ferrari | 216
5 | McLaren | 181
6 | Force India | 155
7 | Toro Rosso | 30
8 | Lotus | 10
9 | Marussia | 2
10 | Sauber | 0
11 | Caterham | 0

Iki 2015 m. Australijos GP liko 95 d. 13 h 16 min.
2014 m. gruodžio 9 d., 18:43

# Karštos naujienos

## Kviečiame išrinkti F-1.LT metų geriausius!

(18) 2014-12-09 00:02 F-1.LT pradeda tradicinius metų geriausiųjų rinkimus. Tai jau 11-asis kartas, kuomet F-1.LT renka geriausią metų lenktynininką, bolidą, naujoką bei kitus įvykius.

- ## Metų rinkimai 2014. Ekspertų nuomonė: A. Baratinskas (3) 2014-12-09 17:02

- ## FE. J.-E. Vergne debiutuos „Formulės-E“ lenktynėse (3) 2014-12-09 07:45

- ## „Lotus“ kitąmet tikisi kovoti su „Williams“ (5) 2014-12-09 07:15

- ## B. Ecclestone’as nusivylė S. Vetteliu (11) 2014-12-09 07:00

- ## „Autosport“ metų lenktynininkas - L. Hamiltonas (2) 2014-12-08 21:23

# Naujienos

Gruodžio 9 d.

## Metų rinkimai 2014. Ekspertų nuomonė: A. Baratinskas (3)

## FE J.-E. Vergne debiutuos „Formulės-E“ lenktynėse (3)

## N. Lauda: kartais aš sunervinu „Mercedes“ valdybą (2)

## „Lotus“ kitąmet tikisi kovoti su „Williams“ (5)

## B. Ecclestone’as nusivylė S. Vetteliu (11)

## Kviečiame išrinkti F-1.LT metų geriausius! (18)

Gruodžio 8 d.

## „Autosport“ metų lenktynininkas – L. Hamiltonas (2)

## J. Buttonas: „McLaren“ delsimas – „keistas“ (28)

## C. Horneris: „Red Bull“ ir „Renault“ 2015 m. sezonui bus geriau pasiruošę (4)

## Pilotų sudėtį delsianti paskelbti „McLaren“: nėra jokios problemos (24)

## „Mercedes“ jaudinasi dėl techninio patikimumo (4)

Gruodžio 7 d.

## Laikas dirba prieš „Renault“ ir „Ferrari“ motoristus (8)

## FIA apdovanojo L. Hamiltoną ir kitus prizininkus (6)

## D. Warwickas: „McLaren“ elgesys – pasibjaurėtinas (16)

## F. Alonso: palikti „Ferrari“ – labai sunku (28)

Gruodžio 6 d.

## Iš „Red Bull“ bazės pavogta 60 trofėjų (30)

## „Lego“ atsisakė remti „McLaren“ ir K. Magnusseną (27)

## F. Williamsas: kodėl jūs džiaugiatės trečiąja vieta? (9)

## S. Domenicali tapo FIA Vienviečių bolidų komisijos prezidentu (2)

## A. Newey buvo susitaręs dėl perėjimo į „Ferrari“? (6)

## Komandoms nebus leista naudoti po 5 variklius per sezoną (8)

Gruodžio 5 d.

## M. Verstappenas pasirinko „Red Bull“ ne dėl vietos F-1 rikiuotėje (9)

## J. Todtas nemato reikalo iš garažo traukti trečiąjį bolidą (9)

## A. Newey ir „Red Bull“ dalyvaus Amerikos Taurės varžybose (11)

## F. Alonso norėtų dalyvauti 24 val. Le Mano lenktynėse (15)

## BBC: „Volkswagen“ svarsto galimybę įžengti į F-1 (9)

## P. Walshas gali tapti naujuoju F-1 valdybos pirmininku (2)

## Sugrįžęs Korėjos etapas: neaišku, ar jis įvyks (2)

Gruodžio 4 d.

## „McLaren“ nepriėmė sprendimo dėl pilotų sudėties (23)

## „Mercedes“: „Red Bull“ norai keisti taisykles paremti savanaudiškais tikslais (20)

## FIA pakoregavo F-1 taisykles (5)

## FIA sugriežtino sąlygas siekiant gauti Super licenciją (8)

## C. Horneris: kitąmet turėsime puikią pilotų porą (5)

RSS Twitter
Daugiau naujienų - archyve

# 2014 m. F-1 sezonas

Tvarkaraštis
Komandos ir lenktynininkai

# Priešsezoniniai bandymai

01-28 – 01-31 | Jerezas (Ispanija)
02-19 – 02-22 | Sakhiras (Bahreinas)
02-27 – 03-02 | Sakhiras (Bahreinas)

# Karštos galerijos

Abu Dabio GP: lenktynės

„Formulės-E“ etapas Malaizijoje

Abu Dabio GP: treniruotės, kvalifikacija

Daugiau nuotraukų...

# GAZAS.LT autonaujienos

Parkavimo ypatybės Panevėžyje

Stasys Brundza pritaria techninės apžiūros atėmimui už netinkamus žibintus

Netikėtinai pigiai benziną pardavinėjančios Klaipėdos degalinės savininkas atskleidė paslaptį

Daugiau autonaujienų...

# F-1.LT tinklaraščiai

Lewis x2

Audi – į F-1 2016-ais???!!!

Deal(s) done?!

AF1@F-1 tinklaraštis | Arūno Braso tinklaraštis

# Tapk mūsų fanu

# Paieška

# Karštos temos diskusijose

| [Parduodu] Knygos (4) | (12-08 21:01)
| F1 žaidimų turnyrų tema (4012) | (12-08 12:53)
| Bianchi crash FIA report (11) | (12-08 12:00)
| Naujienos, gandai... (119) | (12-06 21:42)
| 2014 gandai (1006) | (12-06 19:27)
| Su jumoru apie F-1 :) (2072) | (12-05 13:44)
| La Form moderatorius (21) | (12-04 00:29)
| Quiz: salmai (27) | (12-03 22:30)
| apie lenktyniu matyma (ne ziurejima) (176) | (12-03 10:31)
| Spėlionė (3) | (11-30 20:12)
| Pasiūlymai ir pastabos F-1.LT (1828) | (11-29 11:11)
| Driver rankings 2014 - idomus mat... (7) | (11-28 14:01)
| Svajonių komanda 2014 (559) | (11-27 23:08)
| Musu saunieji komentatoriai :) (4121) | (11-23 19:56)
| Parduodami plastikiniai F-1 model... (24) | (11-23 18:30)

# Diskusijų forumai

Bendrasis forumas
F-1.LT forumas
Techninis forumas
Istorijos forumas
WRC forumas
Žaidimų forumas
„Perku-parduodu“ forumas

# Apklausa

Kaip vertinate 2014 m. sezoną?
Teigiamai | 60%
Neigiamai | 35%
Neturiu nuomonės | 4%
Viso balsų | 282

# El. paštas

El. pašto adresas:
@f-1.lt

Slaptažodis: